
use ${dd}\ed_episodes_cleaned.dta, clear

gen year=year_start

	*Weighting by an HRRs composition in 2011
	bysort qgroup hrr: gen temp_hrrN=_N
	bysort qgroup: gen temp_yearN=_N
	gen temp_hrrprop=temp_hrrN/temp_yearN
	gen temp_2011prop=temp_hrrprop if qgroup==1
	bysort hrr (temp_2011prop): replace temp_2011prop=temp_2011prop[1] if qgroup>1
	replace temp_2011prop=0 if temp_2011prop==.
	gen weight=temp_2011prop/temp_hrrprop
	egen temp_weightsum=total(weight), by(year)
	replace weight=(weight/temp_weightsum)*temp_yearN
	
gen outin_count=1 if in_net_phys_ind==0 & in_net_fac_ind==1 
gen total_eps_fac=1 if in_net_fac_ind==1 

gen year_copy=year_start

keep fac_charge fac_payment phys_charge phys_payment cpi ///
total_eps_fac outin_count year_copy month_start weight hrr qgroup

save ${o}\temp\weighted_quarter_hrr.dta, replace
	
************************************************	
 *Collapse to HRR, then weight using constructed weights from above
 
 use ${o}\temp\weighted_quarter_hrr.dta, clear
	
collapse(sum) outin_count  total_eps_fac  (first) weight year_copy month_start, by(qgroup hrr)

*must have more than 125 episodes per quarter
drop if total_eps_fac<125

*OON rate by HRR and quarter
bysort qgroup hrr: gen inout_ratio=outin_count/total_eps_fac

collapse(mean) inout_ratio (sum) total_eps_fac (first) year_copy month_start [aw=weight], by(qgroup)

scatter inout_ratio qgroup, connect(l) msymbol(i) ylabel(0 "0%" .05 "5%".1 "10%" .15 "15%" .2 "20%" .25 "25%" .3 "30%") legend(off) ///
 xlabel(1 "2011 Q1" 5 "2012 Q1"  9 "2013 Q1" 13 "2014 Q1" 17 "2015 Q1" 21 "2016 Q1", angle(90)) ///
 xmtick(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21, tlength(2) tposition(outside)) ///
 ytitle("Out-of-Network Rate") xtitle("") 
  
 graph export ${o}/final_figures/figures_quarterly_oon.png, width(1500) height(1000) as(png) replace
 
 
