
use ${dd}\ed_episodes_cleaned.dta, clear

*Adjusting for inflation
local pricelist fac_charge fac_payment phys_charge phys_payment medicare_price
foreach l of local pricelist {
	replace `l'=`l'*cpi
}

*Recalculate after trims
drop medicare_pot medicare_poc
gen medicare_pot=phys_payment/medicare_price
gen medicare_poc=phys_charge/medicare_price 


*Calculating payment rates 
summ medicare_pot if in_net_phys_ind==1
	loc adj=r(mean)

*Potential balance bill
	gen medc_adj=medicare_price*`adj'
	gen out_phys_bb=phys_charge-medc_adj if in_net_phys_ind==0

*In-network physician payment, in-network physician payment percent over medicare
	gen in_phys_total= phys_payment if in_net_phys_ind==1
	gen in_phys_pom_tot=medicare_pot if in_net_phys_ind==1

*Out-of-network physician charge, out-of-network physician charge percent over medicare
	gen out_phys_charge= phys_charge if in_net_phys_ind==0
	gen out_phys_pom_provprice=medicare_poc if in_net_phys_ind==0

foreach var of varlist in_phys_pom_tot out_phys_pom_provprice {
	replace `var'=`var'/100
}

*Looking at the mean, sd, and percentiles of the payment rates 
foreach var of varlist out_phys_bb in_phys_total in_phys_pom_tot out_phys_charge out_phys_pom_provprice {
	egen `var'1=mean(`var')
	egen `var'2=sd(`var') 
	egen `var'3=pctile(`var'),p(25)
	egen `var'4=pctile(`var'),p(50)
	egen `var'5=pctile(`var'),p(75) 
	egen `var'6=max(`var') 
}

*Format and prepare for table
keep if _n==1
keep *1 *2 *3 *4 *5 *6
keep in_phys_total* in_phys_pom_tot* out_phys_charge* out_phys_pom_provprice* out_phys_bb*
order in_phys_total* in_phys_pom_tot* out_phys_charge* out_phys_pom_provprice* out_phys_bb*

gen num=1
reshape long inout_ratio out_phys_bb in_phys_total in_phys_pom_tot out_phys_charge out_phys_pom_provprice, i(num) j(new)
drop num new

drop inout_ratio
xpose, clear varname


outsheet * using ${o}\final_tables/summarystats_payments.csv, comma replace






